@@ -10,6 +10,7 @@
 #include <QSqlQuery>
 
 #include <global.h>
+#include <phonenumberlist.h>
 
 
 enum MessageState {
@@ -19,7 +20,7 @@ enum MessageState {
     Failed,
     Received
 };
-Q_DECLARE_METATYPE(MessageState);
+Q_DECLARE_METATYPE(MessageState)
 
 inline MessageState parseMessageState(const QString &state) {
     if (state == SL("pending")) {
@@ -35,22 +36,32 @@ inline MessageState parseMessageState(const QString &state) {
 
 struct Message {
     QString id;
-    QString phoneNumber;
+    PhoneNumberList phoneNumberList;
     QString text;
     QDateTime datetime;
     bool read;
     bool sentByMe;
     MessageState deliveryStatus;
+    QString attachments;
+    QString smil;
+    QString fromNumber;
+    QString messageId;
+    int deliveryReport = 0;
+    QString readReport;
+    bool pendingDownload = false;
+    QString contentLocation;
+    QDateTime expires;
+    int size = 0;
 };
-Q_DECLARE_METATYPE(Message);
+Q_DECLARE_METATYPE(Message)
 
 struct Chat {
-    QString phoneNumber;
+    PhoneNumberList phoneNumberList;
     QDateTime lastContacted;
     QString lastMessage;
     int unreadMessages;
 };
-Q_DECLARE_METATYPE(Chat);
+Q_DECLARE_METATYPE(Chat)
 
 class Database : public QObject
 {
@@ -61,17 +72,21 @@ public:
 
     // Messages
     void addMessage(const Message &message);
-    QVector<Message> messagesForNumber(const QString &phoneNumber) const;
+    void deleteMessage(const QString &id);
+    QVector<Message> messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id = QString()) const;
     void updateMessageDeliveryState(const QString &id, const MessageState state);
+    void updateMessageSent(const QString &id, const QString &messageId, const QString &contentLocation);
+    void updateMessageDeliveryReport(const QString &messageId);
+    void updateMessageReadReport(const QString &messageId, const PhoneNumber &fromNumber);
     void markMessageRead(const int id);
 
     // Chats
     QVector<Chat> chats() const;
-    int unreadMessagesForNumber(const QString &phoneNumber) const;
-    QString lastMessageForNumber(const QString &phoneNumber) const;
-    QDateTime lastContactedForNumber(const QString &phoneNumber) const;
-    void markChatAsRead(const QString &phoneNumber);
-    void deleteChat(const QString &phoneNumber);
+    int unreadMessagesForNumber(const PhoneNumberList &phoneNumberList) const;
+    QString lastMessageForNumber(const PhoneNumberList &phoneNumberList) const;
+    QDateTime lastContactedForNumber(const PhoneNumberList &phoneNumberList) const;
+    void markChatAsRead(const PhoneNumberList &phoneNumberList);
+    void deleteChat(const PhoneNumberList &phoneNumberList);
 
     static QString generateRandomId();
 
@@ -81,10 +96,11 @@ private:
     void migrationV1(uint current);
     void migrationV2(uint current);
     void migrationV3(uint current);
+    void migrationV4(uint current);
     void migrate();
 
     QSqlDatabase m_database;
 
-signals:
-    void messagesChanged(const QString &phoneNumber);
+Q_SIGNALS:
+    void messagesChanged(const PhoneNumberList &phoneNumberList);
 };
